summaryrefslogtreecommitdiff
path: root/include/gtest/gtest-message.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/gtest/gtest-message.h')
-rw-r--r--include/gtest/gtest-message.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/gtest/gtest-message.h b/include/gtest/gtest-message.h
index 9b7142f..6336b4a 100644
--- a/include/gtest/gtest-message.h
+++ b/include/gtest/gtest-message.h
@@ -183,11 +183,11 @@ class GTEST_API_ Message {
Message& operator <<(const ::wstring& wstr);
#endif // GTEST_HAS_GLOBAL_WSTRING
// Gets the text streamed to this object so far as a String.
// Each '\0' character in the buffer is replaced with "\\0".
//
// INTERNAL IMPLEMENTATION - DO NOT USE IN A USER PROGRAM.
- internal::String GetString() const {
+ std::string GetString() const {
return internal::StringStreamToString(ss_.get());
}
@@ -183,11 +183,11 @@ class GTEST_API_ Message {
Message& operator <<(const ::wstring& wstr);
#endif // GTEST_HAS_GLOBAL_WSTRING
- // Gets the text streamed to this object so far as a String.
+ // Gets the text streamed to this object so far as an std::string.
// Each '\0' character in the buffer is replaced with "\\0".
//